<?php
/**
 * @file
 * Ctools access plugin for checking if a view returns results.
 */
/**
 * Plugins are described by creating a $plugin array which will
 * be used by the system that includes the file.
 */
$plugin = array(
  'title' => t('View: A view returns results'),
  'description' => t('Controls access by checking if the specified view returns a result'),
  'callback' => 'ctools_view_access_view_access_ctools_access_check',
  'settings form' => 'ctools_view_access_view_access_ctools_settings',
  'settings form submit' => 'ctools_view_access_view_access_ctools_settings_submit',
  'summary' => 'ctools_view_access_view_access_ctools_summary',
);
/**
 * Custom callback defined by 'callback' in the $plugin array.
 *
 * Check for access.
 */
function ctools_view_access_view_access_ctools_access_check($conf, $context) {
  // Check if the View returns results
  list($view_name, $view_id) = explode(':', $conf['view_instance']);
  $result = views_get_view_result($view_name,$view_id);
  if (!empty($result)) {
    return TRUE;
  }
  return FALSE;
}
/**
 * Settings form for the 'view_access' access plugin.
 */
function ctools_view_access_view_access_ctools_settings($form, &$form_state, $conf) {
  $view_list = views_get_all_views();
  $views_options = array();
  // Loop through each view adding each instance to the view options array
  foreach($view_list as $view_parent_name => $view_object) {
    foreach($view_object->display as $view_instance => $view_instance_name) {
      // Fixes Nodequeue Views with empty $view_object->human_name values.
      $name = ($view_object->human_name) ? $view_object->human_name : $view_object->name;
      $views_options[$view_parent_name . ':' . $view_instance_name->id] = $name . ' - ' . $view_instance;
    }
  }
  $form['settings']['view_instance'] = array(
    '#type' => 'select',
    '#title' => t('View name - Display id'),
    '#description' => t('If the view selected returns results, access will return TRUE (block/pane will be visible)'),
    '#default_value' => $conf['view_instance'],
    '#options' => $views_options,
  );
  // Pass the labels so we an easily match them upon submission
  $form['settings']['view_instance_labels'] = array(
    '#type' => 'value',
    '#value' => $views_options,
  );
  return $form;
}
/**
 * Custom submit handler to save the pretty label in the conf array
 */
function ctools_view_access_view_access_ctools_settings_submit($form, &$form_state) {
  $form_state['values']['settings']['label'] = $form_state['values']['settings']['view_instance_labels'][$form_state['values']['settings']['view_instance']];
  unset($form_state['values']['settings']['view_instance_labels']);
}
/**
 * Provide a summary description
 */
function ctools_view_access_view_access_ctools_summary($conf, $context) {
  // Here we use the label value so its pretty
  return t('View @label has been populated', array('@label' => $conf['label']));
}
